@@ -319,6 +319,7 @@ class MiniRpaManager(MiniRpaFunction):
             config_sheet_name = self.process_dict.get('config_sheet_name', 'Sheet1')
             compare_result_file_name = self.prepare_file_name(self.process_dict.get('compare_result_file_name', ''))
             no_difference_file_name = self.prepare_file_name(self.process_dict.get('no_difference_file_name', ''))
+            transpose_result_file_name = self.prepare_file_name(self.process_dict.get('transpose_result_file_name', ''))
 
             public_folder_path = self.replace_variables_in_string(self.process_dict.get('public_folder_path', ''))
             report_save_path = self.replace_variables_in_string(self.process_dict.get('report_save_path', ''))
@@ -458,6 +459,9 @@ class MiniRpaManager(MiniRpaFunction):
                 self.hrs_collect_row_value_diffs(from_folder_path, from_file_name, from_sheet_name, from_column_by, update_folder_path,
                                                  update_file_name, update_sheet_name, update_column_by, config_folder_path, config_file_name, config_sheet_name,
                                                  compare_result_file_name, no_difference_file_name)
+            elif function_name == 'hrs_transpose_excel_row_data':
+                self.hrs_transpose_excel_row_data(from_folder_path, from_file_name, from_sheet_name, config_folder_path, config_file_name, config_sheet_name,
+                                                  transpose_result_file_name)
             elif function_name == 'save_pdf_table_into_excel':
                 (pdf_folder_path, pdf_file_name, page_number, table_index, first_column_name, save_column_names, excel_folder_path, excel_file_name, sheet_name, extract_all_pages,
                  extract_all_tables) = (
