@@ -226,7 +226,26 @@ class MiniRpaSapAutomation:
         Args:
             radio_checkbox_title(str): This is the title of radio or checkbox
         """
-        self.web_rpa.click_or_input_by_css_selector(f"span[title='{radio_checkbox_title}']", 'click')
+        wait_time = 60
+        while wait_time > 0:
+            try:
+                self.web_rpa.browser.find_element(By.CSS_SELECTOR, f"span[title='{radio_checkbox_title}']")
+                self.web_rpa.click_or_input_by_css_selector(f"span[title='{radio_checkbox_title}']", 'click')
+                return
+            except NoSuchElementException:
+                try:
+                    self.web_rpa.browser.find_element(By.CSS_SELECTOR, f"span[aria-label='{radio_checkbox_title}']")
+                    self.web_rpa.click_or_input_by_css_selector(f"span[aria-label='{radio_checkbox_title}']", 'click')
+                    return
+                except NoSuchElementException:
+                    sleep(1)
+                    wait_time -= 1
+        raise Exception(f"Cannot find radio or checkbox with title: {radio_checkbox_title}")
+
+        # try:
+        #     self.web_rpa.click_or_input_by_css_selector(f"span[title='{radio_checkbox_title}']", 'click')
+        # except:
+        #     self.web_rpa.click_or_input_by_css_selector(f"span[aria-label='{radio_checkbox_title}']", 'click')
 
     def click_button(self, button_title):
         """ This function is used to click button in SE16.
